ryvencore.NodePortBP module - ryvencore v0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Toggle table of contents sidebar

# ryvencore.NodePortBP module

class NodePortBP(label: str = '', type_: str = 'data')

  Bases: `object`

  The NodePortBPs (NodeInputs and NodeOutputs) are only placeholders (BluePrints) for the static init_input and init_outputs of custom Node classes. An instantiated Node’s actual inputs and outputs will be of type NodeObjPort (NodeObjInput, NodeObjOutput).

class NodeInputBP(label: str = '', type_: str = 'data', dtype: Optional[ryvencore.dtypes.dtypes.DType] = None, add_data={})

  Bases: `ryvencore.NodePortBP.NodePortBP`

class NodeOutputBP(label: str = '', type_: str = 'data')

  Bases: `ryvencore.NodePortBP.NodePortBP`